==> openjdk-11_11~24.orig.tar.xz: openjdk-11-11~24/test/hotspot/jtreg/gc/arguments/TestUseNUMAInterleaving.java <==
/*
 * Copyright (c) 2014, 2016, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/**
 * @test TestUseNUMAInterleaving
 * @summary Tests that UseNUMAInterleaving enabled for all collectors by
 * ergonomics, on all platforms when UseNUMA feature is enabled.
 * @bug 8059614
 * @key gc
 * @library /test/lib
 * @modules java.base/jdk.internal.misc
 *          java.management
 * @run driver TestUseNUMAInterleaving
 */
import jdk.test.lib.process.OutputAnalyzer;
import jdk.test.lib.process.ProcessTools;

public class TestUseNUMAInterleaving {

    public static void main(String[] args) throws Exception {
        String[] vmargs = new String[]{
            "-XX:+UseNUMA",
            "-XX:+PrintFlagsFinal",
            "-version"
        };
        ProcessBuilder pb = ProcessTools.createJavaProcessBuilder(true, vmargs);
        OutputAnalyzer output = new OutputAnalyzer(pb.start());

        boolean isNUMAEnabled
                = Boolean.parseBoolean(output.firstMatch(NUMA_FLAG_PATTERN, 1));

        if (isNUMAEnabled) {
            output.shouldMatch("\\bUseNUMAInterleaving\\b.*?=.*?true");
            System.out.println(output.getStdout());
        } else {
            System.out.println(output.firstMatch(NUMA_FLAG_PATTERN));
            System.out.println(output.firstMatch(NUMA_FLAG_PATTERN, 1));
        }
    }

    private static final String NUMA_FLAG_PATTERN = "\\bUseNUMA\\b.*?=.*?([a-z]+)";
}

==> openjdk-14_14~19.orig.tar.xz: openjdk-14-14~19/test/hotspot/jtreg/gc/arguments/TestUseNUMAInterleaving.java <==
/*
 * Copyright (c) 2014, 2019, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

package gc.arguments;

/**
 * @test TestUseNUMAInterleaving
 * @summary Tests that UseNUMAInterleaving enabled for all collectors by
 * ergonomics, on all platforms when UseNUMA feature is enabled.
 * @bug 8059614
 * @key gc
 * @library /test/lib
 * @library /
 * @modules java.base/jdk.internal.misc
 *          java.management
 * @run driver gc.arguments.TestUseNUMAInterleaving
 */
import jdk.test.lib.process.OutputAnalyzer;
import jdk.test.lib.process.ProcessTools;

public class TestUseNUMAInterleaving {

    public static void main(String[] args) throws Exception {
        String[] vmargs = new String[]{
            "-XX:+UseNUMA",
            "-XX:+PrintFlagsFinal",
            "-version"
        };
        ProcessBuilder pb = GCArguments.createJavaProcessBuilder(true, vmargs);
        OutputAnalyzer output = new OutputAnalyzer(pb.start());

        boolean isNUMAEnabled
                = Boolean.parseBoolean(output.firstMatch(NUMA_FLAG_PATTERN, 1));

        if (isNUMAEnabled) {
            output.shouldMatch("\\bUseNUMAInterleaving\\b.*?=.*?true");
            System.out.println(output.getStdout());
        } else {
            System.out.println(output.firstMatch(NUMA_FLAG_PATTERN));
            System.out.println(output.firstMatch(NUMA_FLAG_PATTERN, 1));
        }
    }

    private static final String NUMA_FLAG_PATTERN = "\\bUseNUMA\\b.*?=.*?([a-z]+)";
}
